.. _home:


.. raw:: html

    <br>


.. title:: Reconsider OTP-CR-117/19



Geachte heer Aardema,

ik wil u graag informeren dat uw commissies van VWS en J&V geinformeerd zijn dat de medcijnen gebruikt in de gedwongen zorg waar uw wet een wettelijk voorschrift voor gaat bieden gif blijken te zijn.

Er is bewijs dat de medcijnen gebruikt in de GGZ gif zijn, bewijs dat geleverd word door het ECHA agentschap van de Europeese Unie, wat bij houd welke chemicalien een gevaar zijn of niet. De ECHA laat bedrijven die stoffen willen transporteren testen doen wat hun dodelijkheid betreft, de zogenoemde LD-50 tests. Aan de hand van deze tests beoordeelt men dan of een stof onschadelijk, schadelijk, gif of dodelijk zijn. Deze tests resulteren in labels die men moet gebruiken als men de stof transporteert.


Voor de stof haloperiodol, de werkzame stof in Haldol, ziet u hier de waarschuwingen die te vinden zijn op:


https://echa.europa.eu/substance-information/-/substanceinfo/100.000.142


Haldol is het meest gebruikt medicijn als "nood medicatie" in de GGZ, een klassiek antipsychoticum.


bewijs dat haldol gif is:

 .. image:: jpg/ECHAhaloperidol.png
    :width: 100%

Zoals u ziet is haloperidol geclassificeerd als "toxic as swallowed" en is een doodskop met beenderen noodzakelijk als men deze stof wil vervoeren.

Men gebruikt in de GGZ dus geen medicijnen die geen schade kunnen, maar een stof die giftig is als men hem inneemt.

De medicatie die u in uw wet toestaat om gedwongen toegedient te kunnen worden zijn gif en niet zoals men beweerd een medicijn dat geen schade kan.

Deze wet aannemen in de wetenschap dat het hier gif betreft maakt dat uw wettelijke voorschrift gebruikt word voor giftoedieningen en niet voor behandeling met medicijnen die geen schade kunnen.

U zekert hier de straffeloosheid voor deze gif toedieningen als u niet ook zorgt dat de medicatie waar uw wet aan refereert ook niet daadwerkelijk medicijnen zijn die geen schade kunnen.

Ik hoop dat u de wetenschap dat het hier gif betreft en niet medicatie zult gebruiken om de WvGGZ niet aan te nemen, hij word nu gebruikt in een poging gif toedieningen te legaliseren, te voorzien van een wettelijk voorschrift.


Hoogachtend,


Bart Thate


p.s. de commissies VWS en J&V van uw kamer zijn ook geinformeerd maar uw persoonlijk ook op de hoogte brengen voordat men hier over stemt verdient de voorkeur.


.. raw:: html

   <br>


.. raw:: html

   <br><br>


.. image:: jpg/bevestigd3.jpg
    :width: 100%


.. image:: jpg/bevestigd.jpg
    :width: 100%


.. toctree::
    :glob:
    :hidden:

    *
    txt/*
